@@ -1,6 +1,9 @@
+pub mod address;
 pub mod bar;
 pub mod consts;
 pub mod driver;
 pub mod ftp;
+pub mod hash;
 pub mod https;
-pub mod output;
+pub mod io;
+pub mod slicer;
