@@ -13,6 +13,8 @@ async fn main() {
             * Downloading: if filename supplied, writes to file, otherwise stdout (cannot resume).\n\
             * Uploading: directly uploads file to URL.\n\
             * if none present, writes to stdout.")
+        
+        (@arg SHA256: +takes_value "Expected sha256 for verification. Will return a non-zero if mismatch")
     )
     .get_matches_safe()
     .unwrap_or_else(|e| e.exit());
@@ -20,6 +22,12 @@ async fn main() {
     let input = args.value_of("INPUT").unwrap();
     let output = args.value_of("OUTPUT").unwrap_or("stdout");
     let silent = args.is_present("silent");
+    let expected_sha256 = args.value_of("SHA256").unwrap_or("");
 
-    aim::driver::Driver::drive(input, output, silent).await;
+    let result  = aim::driver::Driver::drive(input, output, silent, expected_sha256).await;
+    if result{
+        std::process::exit(0);
+    } else {
+        std::process::exit(255);
+    }
 }
